@@ -39,9 +39,6 @@ from glance_store.tests import base
 from tests.unit import test_store_capabilities
 
 
-KB = 1024
-
-
 class TestStore(base.StoreBaseTest,
                 test_store_capabilities.TestStoreCapabilitiesChecking):
 
@@ -52,8 +49,10 @@ class TestStore(base.StoreBaseTest,
         Store.READ_CHUNKSIZE = 10
         self.store = Store(self.conf)
         self.config(filesystem_store_datadir=self.test_dir,
+                    stores=['glance.store.filesystem.Store'],
                     group="glance_store")
         self.store.configure()
+        self.register_store_schemes(self.store, 'file')
 
     def tearDown(self):
         """Clear the test environment."""
@@ -155,9 +154,9 @@ class TestStore(base.StoreBaseTest,
 
     def test_add(self):
         """Test that we can add an image via the filesystem backend."""
-        ChunkedFile.CHUNKSIZE = 1024
+        ChunkedFile.CHUNKSIZE = units.Ki
         expected_image_id = str(uuid.uuid4())
-        expected_file_size = 5 * KB  # 5K
+        expected_file_size = 5 * units.Ki  # 5K
         expected_file_contents = "*" * expected_file_size
         expected_checksum = hashlib.md5(expected_file_contents).hexdigest()
         expected_location = "file://%s/%s" % (self.test_dir,
@@ -225,9 +224,9 @@ class TestStore(base.StoreBaseTest,
         Tests that adding an image with an existing identifier
         raises an appropriate exception
         """
-        ChunkedFile.CHUNKSIZE = 1024
+        ChunkedFile.CHUNKSIZE = units.Ki
         image_id = str(uuid.uuid4())
-        file_size = 5 * KB  # 5K
+        file_size = 5 * units.Ki  # 5K
         file_contents = "*" * file_size
         image_file = StringIO.StringIO(file_contents)
 
@@ -240,9 +239,9 @@ class TestStore(base.StoreBaseTest,
                           image_id, image_file, 0)
 
     def _do_test_add_write_failure(self, errno, exception):
-        ChunkedFile.CHUNKSIZE = 1024
+        ChunkedFile.CHUNKSIZE = units.Ki
         image_id = str(uuid.uuid4())
-        file_size = 5 * KB  # 5K
+        file_size = 5 * units.Ki  # 5K
         file_contents = "*" * file_size
         path = os.path.join(self.test_dir, image_id)
         image_file = StringIO.StringIO(file_contents)
@@ -291,9 +290,9 @@ class TestStore(base.StoreBaseTest,
         Tests the partial image file is cleaned up after a read
         failure.
         """
-        ChunkedFile.CHUNKSIZE = 1024
+        ChunkedFile.CHUNKSIZE = units.Ki
         image_id = str(uuid.uuid4())
-        file_size = 5 * KB  # 5K
+        file_size = 5 * units.Ki  # 5K
         file_contents = "*" * file_size
         path = os.path.join(self.test_dir, image_id)
         image_file = StringIO.StringIO(file_contents)
@@ -315,7 +314,7 @@ class TestStore(base.StoreBaseTest,
         """
         # First add an image
         image_id = str(uuid.uuid4())
-        file_size = 5 * KB  # 5K
+        file_size = 5 * units.Ki  # 5K
         file_contents = "*" * file_size
         image_file = StringIO.StringIO(file_contents)
 
@@ -341,6 +340,38 @@ class TestStore(base.StoreBaseTest,
                           self.store.delete,
                           loc)
 
+    def test_delete_forbidden(self):
+        """
+        Tests that trying to delete a file without permissions
+        raises the correct error
+        """
+        # First add an image
+        image_id = str(uuid.uuid4())
+        file_size = 5 * units.Ki  # 5K
+        file_contents = "*" * file_size
+        image_file = StringIO.StringIO(file_contents)
+
+        loc, size, checksum, _ = self.store.add(image_id,
+                                                image_file,
+                                                file_size)
+
+        uri = "file:///%s/%s" % (self.test_dir, image_id)
+        loc = location.get_location_from_uri(uri, conf=self.conf)
+
+        # Mock unlink to raise an OSError for lack of permissions
+        # and make sure we can't delete the image
+        with mock.patch.object(os, 'unlink') as unlink:
+            e = OSError()
+            e.errno = errno
+            unlink.side_effect = e
+
+            self.assertRaises(exceptions.Forbidden,
+                              self.store.delete,
+                              loc)
+
+            # Make sure the image didn't get deleted
+            self.store.get(loc)
+
     def test_configure_add_with_multi_datadirs(self):
         """
         Tests multiple filesystem specified by filesystem_store_datadirs
@@ -454,6 +485,56 @@ class TestStore(base.StoreBaseTest,
         self.assertRaises(exceptions.BadStoreConfiguration,
                           self.store.configure_add)
 
+    def test_configure_add_same_dir_multiple_times_same_priority(self):
+        """
+        Tests BadStoreConfiguration exception is raised if same directory
+        is specified multiple times in filesystem_store_datadirs.
+        """
+        store_map = [self.useFixture(fixtures.TempDir()).path,
+                     self.useFixture(fixtures.TempDir()).path]
+        self.conf.clear_override('filesystem_store_datadir',
+                                 group='glance_store')
+        self.conf.set_override('filesystem_store_datadirs',
+                               [store_map[0] + ":100",
+                                store_map[1] + ":200",
+                                store_map[0] + ":100"],
+                               group='glance_store')
+        try:
+            self.store.configure()
+        except exceptions.BadStoreConfiguration:
+            self.fail("configure() raised BadStoreConfiguration unexpectedly!")
+
+        # Test that we can add an image via the filesystem backend
+        ChunkedFile.CHUNKSIZE = 1024
+        expected_image_id = str(uuid.uuid4())
+        expected_file_size = 5 * units.Ki  # 5K
+        expected_file_contents = "*" * expected_file_size
+        expected_checksum = hashlib.md5(expected_file_contents).hexdigest()
+        expected_location = "file://%s/%s" % (store_map[1],
+                                              expected_image_id)
+        image_file = six.StringIO(expected_file_contents)
+
+        loc, size, checksum, _ = self.store.add(expected_image_id,
+                                                image_file,
+                                                expected_file_size)
+
+        self.assertEqual(expected_location, loc)
+        self.assertEqual(expected_file_size, size)
+        self.assertEqual(expected_checksum, checksum)
+
+        loc = location.get_location_from_uri(expected_location,
+                                             conf=self.conf)
+        (new_image_file, new_image_size) = self.store.get(loc)
+        new_image_contents = ""
+        new_image_file_size = 0
+
+        for chunk in new_image_file:
+            new_image_file_size += len(chunk)
+            new_image_contents += chunk
+
+        self.assertEqual(expected_file_contents, new_image_contents)
+        self.assertEqual(expected_file_size, new_image_file_size)
+
     def test_add_with_multiple_dirs(self):
         """Test adding multiple filesystem directories."""
         store_map = [self.useFixture(fixtures.TempDir()).path,
@@ -467,8 +548,8 @@ class TestStore(base.StoreBaseTest,
 
         self.store.configure()
 
-        """Test that we can add an image via the filesystem backend"""
-        ChunkedFile.CHUNKSIZE = 1024
+        # Test that we can add an image via the filesystem backend
+        ChunkedFile.CHUNKSIZE = units.Ki
         expected_image_id = str(uuid.uuid4())
         expected_file_size = 5 * units.Ki  # 5K
         expected_file_contents = "*" * expected_file_size
@@ -520,7 +601,7 @@ class TestStore(base.StoreBaseTest,
         with mock.patch.object(self.store, '_get_capacity_info') as capacity:
             capacity.return_value = 0
 
-            ChunkedFile.CHUNKSIZE = 1024
+            ChunkedFile.CHUNKSIZE = units.Ki
             expected_image_id = str(uuid.uuid4())
             expected_file_size = 5 * units.Ki  # 5K
             expected_file_contents = "*" * expected_file_size
@@ -573,7 +654,7 @@ class TestStore(base.StoreBaseTest,
 
         self.store.configure_add()
 
-        Store.WRITE_CHUNKSIZE = 1024
+        Store.WRITE_CHUNKSIZE = units.Ki
         expected_image_id = str(uuid.uuid4())
         expected_file_size = 5 * units.Ki  # 5K
         expected_file_contents = "*" * expected_file_size
@@ -614,7 +695,7 @@ class TestStore(base.StoreBaseTest,
 
         self.store.configure_add()
 
-        Store.WRITE_CHUNKSIZE = 1024
+        Store.WRITE_CHUNKSIZE = units.Ki
         expected_image_id = str(uuid.uuid4())
         expected_file_size = 5 * units.Ki  # 5K
         expected_file_contents = "*" * expected_file_size
