@@ -32,6 +32,7 @@ class TestHttpStore(base.StoreBaseTest,
         self.config(default_store='http', group='glance_store')
         http.Store.READ_CHUNKSIZE = 2
         self.store = http.Store(self.conf)
+        self.register_store_schemes(self.store, 'http')
 
     def _mock_httplib(self):
         """Mock httplib connection object.
@@ -60,6 +61,12 @@ class TestHttpStore(base.StoreBaseTest,
         chunks = [c for c in image_file]
         self.assertEqual(expected_returns, chunks)
 
+    def test_http_partial_get(self):
+        uri = "http://netloc/path/to/file.tar.gz"
+        loc = location.get_location_from_uri(uri, conf=self.conf)
+        self.assertRaises(exceptions.StoreRandomGetNotSupported,
+                          self.store.get, loc, chunk_size=1)
+
     def test_http_get_redirect(self):
         # Add two layers of redirects to the response stack, which will
         # return the default 200 OK with the expected data after resolving
@@ -133,7 +140,7 @@ class TestHttpStore(base.StoreBaseTest,
                           self.store.add, None, None, None, None)
         self.assertRaises(exceptions.StoreAddDisabled,
                           glance_store.add_to_backend, None, None,
-                          None, None, 'file')
+                          None, None, 'http')
 
     def test_http_get_size_with_non_existent_image_raises_Not_Found(self):
         self._mock_httplib()
